==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/amber/cfg/ColumnConfig.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Rodrigo Westrupp
 */

package com.caucho.amber.cfg;

import javax.persistence.Column;

/**
 * <column> tag in the orm.xml
 */
public class ColumnConfig extends AbstractColumnConfig {

  // attributes
  private int _length;
  private int _precision;
  private int _scale;

  /**
   * Returns the length.
   */
  public int getLength()
  {
    return _length;
  }

  /**
   * Sets the length.
   */
  public void setLength(int length)
  {
    _length = length;
  }

  /**
   * Returns the precision.
   */
  public int getPrecision()
  {
    return _precision;
  }

  /**
   * Sets the precision.
   */
  public void setPrecision(int precision)
  {
    _precision = precision;
  }

  /**
   * Returns the scale.
   */
  public int getScale()
  {
    return _scale;
  }

  /**
   * Sets the scale.
   */
  public void setScale(int scale)
  {
    _scale = scale;
  }

  /**
   * Fill the column value by introspection
   */
  public void introspect(Column column)
  {
    setName(column.name());
    setUnique(column.unique());
    setNullable(column.nullable());
    setInsertable(column.insertable());
    setUpdatable(column.updatable());
    setColumnDefinition(column.columnDefinition());
    setTable(column.table());

    setLength(column.length());
    setPrecision(column.precision());
    setScale(column.scale());
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/amber/cfg/ColumnConfig.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Rodrigo Westrupp
 */

package com.caucho.amber.cfg;

import javax.persistence.Column;

/**
 * <column> tag in the orm.xml
 */
public class ColumnConfig extends AbstractColumnConfig {

  // attributes
  private int _length = 255;
  private int _precision;
  private int _scale;
  
  public ColumnConfig()
  {
  }
  
  public ColumnConfig(Column column)
  {
    setName(column.name());
    setUnique(column.unique());
    setNullable(column.nullable());
    setInsertable(column.insertable());
    setUpdatable(column.updatable());
    setColumnDefinition(column.columnDefinition());
    setTable(column.table());
    setLength(column.length());
    setPrecision(column.precision());
    setScale(column.scale());
  }

  /**
   * Returns the length.
   */
  public int getLength()
  {
    return _length;
  }

  /**
   * Sets the length.
   */
  public void setLength(int length)
  {
    _length = length;
  }

  /**
   * Returns the precision.
   */
  public int getPrecision()
  {
    return _precision;
  }

  /**
   * Sets the precision.
   */
  public void setPrecision(int precision)
  {
    _precision = precision;
  }

  /**
   * Returns the scale.
   */
  public int getScale()
  {
    return _scale;
  }

  /**
   * Sets the scale.
   */
  public void setScale(int scale)
  {
    _scale = scale;
  }

  /**
   * Fill the column value by introspection
   */
  public void introspect(Column column)
  {
    setName(column.name());
    setUnique(column.unique());
    setNullable(column.nullable());
    setInsertable(column.insertable());
    setUpdatable(column.updatable());
    setColumnDefinition(column.columnDefinition());
    setTable(column.table());

    setLength(column.length());
    setPrecision(column.precision());
    setScale(column.scale());
  }
}
